@@ -40,8 +40,9 @@ def parser():
     if html.status_code == 200:
         soup = BeautifulSoup(html.text, 'html.parser')
         items = soup.find_all('div', class_='structure-row flex')
+        items.append(soup.find('div', class_='structure-row flex structure-row--apparat-first'))
         for item in items:
-            arr = item.find_all('a', class_='person flex flex-center-v col-4')
+            arr = item.find_all('a')
             for ar in arr:
                 work = ar.get_text()
                 work = work.split(maxsplit=3)
